@@ -35,18 +35,19 @@ class Grid(object):
     """
 
     def __init__(self, lon, lat, time, time_origin, mesh):
+        self.xi = None
+        self.yi = None
+        self.zi = None
+        self.ti = -1
         self.lon = lon
         self.lat = lat
         self.time = np.zeros(1, dtype=np.float64) if time is None else time
         if not self.lon.dtype == np.float32:
-            logger.warning_once("Casting lon data to np.float32")
             self.lon = self.lon.astype(np.float32)
         if not self.lat.dtype == np.float32:
-            logger.warning_once("Casting lat data to np.float32")
             self.lat = self.lat.astype(np.float32)
         if not self.time.dtype == np.float64:
             assert isinstance(self.time[0], (np.integer, np.floating, float, int)), 'Time vector must be an array of int or floats'
-            logger.warning_once("Casting time data to np.float64")
             self.time = self.time.astype(np.float64)
         self.time_full = self.time  # needed for deferred_loaded Fields
         self.time_origin = TimeConverter() if time_origin is None else time_origin
@@ -212,7 +213,7 @@ class Grid(object):
                 if signdt == -1 and self.ti == 0 and (time - periods*(self.time_full[-1]-self.time_full[0])) == self.time[0] and f.time_periodic:
                     self.ti = len(self.time)-1
                     periods -= 1
-                if signdt == -1 and self.ti > 0:
+                if signdt == -1 and self.ti > 0 and self.time_full[self.ti] == time:
                     self.ti -= 1
                 if self.ti >= len(self.time_full) - 1:
                     self.ti = len(self.time_full) - 2
@@ -274,7 +275,8 @@ class RectilinearGrid(Grid):
         if self.ydim > 1 and self.lat[-1] < self.lat[0]:
             self.lat = np.flip(self.lat, axis=0)
             self.lat_flipped = True
-            logger.warning_once("Flipping lat data from North-South to South-North")
+            logger.warning_once("Flipping lat data from North-South to South-North. "
+                                "Note that this may lead to wrong sign for meridional velocity, so tread very carefully")
 
     def add_periodic_halo(self, zonal, meridional, halosize=5):
         """Add a 'halo' to the Grid, through extending the Grid (and lon/lat)
@@ -333,7 +335,6 @@ class RectilinearZGrid(RectilinearGrid):
         self.zdim = self.depth.size
         self.z4d = -1  # only used in RectilinearSGrid
         if not self.depth.dtype == np.float32:
-            logger.warning_once("Casting depth data to np.float32")
             self.depth = self.depth.astype(np.float32)
 
 
@@ -377,7 +378,6 @@ class RectilinearSGrid(RectilinearGrid):
             assert self.xdim == self.depth.shape[-1], 'depth dimension has the wrong format. It should be [zdim, ydim, xdim]'
             assert self.ydim == self.depth.shape[-2], 'depth dimension has the wrong format. It should be [zdim, ydim, xdim]'
         if not self.depth.dtype == np.float32:
-            logger.warning_once("Casting depth data to np.float32")
             self.depth = self.depth.astype(np.float32)
         if self.lat_flipped:
             self.depth = np.flip(self.depth, axis=-2)
@@ -465,7 +465,6 @@ class CurvilinearZGrid(CurvilinearGrid):
         self.zdim = self.depth.size
         self.z4d = -1  # only for SGrid
         if not self.depth.dtype == np.float32:
-            logger.warning_once("Casting depth data to np.float32")
             self.depth = self.depth.astype(np.float32)
 
 
@@ -508,5 +507,4 @@ class CurvilinearSGrid(CurvilinearGrid):
             assert self.xdim == self.depth.shape[-1], 'depth dimension has the wrong format. It should be [zdim, ydim, xdim]'
             assert self.ydim == self.depth.shape[-2], 'depth dimension has the wrong format. It should be [zdim, ydim, xdim]'
         if not self.depth.dtype == np.float32:
-            logger.warning_once("Casting depth data to np.float32")
             self.depth = self.depth.astype(np.float32)
